.. _fluent_pages.models:

fluent_pages.models
=====================

.. automodule:: fluent_pages.models

The ``UrlNode`` class
------------------------------------

.. autoclass:: fluent_pages.models.UrlNode
   :members:

The ``Page`` class
-----------------------------------

.. autoclass:: fluent_pages.models.Page
   :members:

The ``HtmlPage`` class
-----------------------------------

.. autoclass:: fluent_pages.models.HtmlPage
   :members:

The ``PageLayout`` class
-----------------------------------

.. autoclass:: fluent_pages.models.PageLayout
   :members:

The ``UrlNodeManager`` class
------------------------------------

.. autoclass:: fluent_pages.models.UrlNodeManager
   :members:
